@@ -33,29 +33,47 @@ class FastApiResponse(BaseResponse):
     def set_html_content(self, content: str):
         if not self.response_sent:
             body = bytes(content, "utf-8")
-            self.set_header('Content-Length', str(len(body)))
-            self.set_header('Content-Type', 'text/html')
+            self.set_header("Content-Length", str(len(body)))
+            self.set_header("Content-Type", "text/html")
             self.response.body = body
             self.response_sent = True
 
-    def set_cookie(self, key: str,
-                   value: str,
-                   expires: int,
-                   path: str = "/",
-                   domain: Union[str, None] = None,
-                   secure: bool = False,
-                   httponly: bool = False,
-                   samesite: str = "lax"):
+    def set_cookie(
+        self,
+        key: str,
+        value: str,
+        expires: int,
+        path: str = "/",
+        domain: Union[str, None] = None,
+        secure: bool = False,
+        httponly: bool = False,
+        samesite: str = "lax",
+    ):
         if domain is None:
             # we do ceil because if we do floor, we tests may fail where the access
             # token lifetime is set to 1 second
-            self.response.set_cookie(key=key, value=value, expires=ceil((expires - int(time() * 1000)) / 1000),
-                                     path=path, secure=secure, httponly=httponly, samesite=samesite)
+            self.response.set_cookie(
+                key=key,
+                value=value,
+                expires=ceil((expires - int(time() * 1000)) / 1000),
+                path=path,
+                secure=secure,
+                httponly=httponly,
+                samesite=samesite,
+            )
         else:
             # we do ceil because if we do floor, we tests may fail where the access
             # token lifetime is set to 1 second
-            self.response.set_cookie(key=key, value=value, expires=ceil((expires - int(time() * 1000)) / 1000),
-                                     path=path, domain=domain, secure=secure, httponly=httponly, samesite=samesite)
+            self.response.set_cookie(
+                key=key,
+                value=value,
+                expires=ceil((expires - int(time() * 1000)) / 1000),
+                path=path,
+                domain=domain,
+                secure=secure,
+                httponly=httponly,
+                samesite=samesite,
+            )
 
     def set_header(self, key: str, value: str):
         self.response.headers[key] = value
@@ -77,7 +95,7 @@ class FastApiResponse(BaseResponse):
                 indent=None,
                 separators=(",", ":"),
             ).encode("utf-8")
-            self.set_header('Content-Type', 'application/json; charset=utf-8')
-            self.set_header('Content-Length', str(len(body)))
+            self.set_header("Content-Type", "application/json; charset=utf-8")
+            self.set_header("Content-Length", str(len(body)))
             self.response.body = body
             self.response_sent = True
