@@ -14,26 +14,37 @@
 
 from typing import Any, Dict, Callable, Union
 
-from supertokens_python.ingredients.emaildelivery.services.smtp import (
-    Transporter)
-from supertokens_python.ingredients.emaildelivery.types import \
-    EmailDeliveryInterface, SMTPServiceInterface, SMTPSettings
-from supertokens_python.recipe.emailpassword.types import \
-    EmailTemplateVars, SMTPOverrideInput
-from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import \
-    SMTPService as EmailVerificationSMTPService
-from supertokens_python.recipe.emailverification.types import VerificationEmailTemplateVars
+from supertokens_python.ingredients.emaildelivery.services.smtp import Transporter
+from supertokens_python.ingredients.emaildelivery.types import (
+    EmailDeliveryInterface,
+    SMTPServiceInterface,
+    SMTPSettings,
+)
+from supertokens_python.recipe.emailpassword.types import (
+    EmailTemplateVars,
+    SMTPOverrideInput,
+)
+from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import (
+    SMTPService as EmailVerificationSMTPService,
+)
+from supertokens_python.recipe.emailverification.types import (
+    VerificationEmailTemplateVars,
+)
 
 from .service_implementation import ServiceImplementation
-from .service_implementation.email_verification_implementation import \
-    ServiceImplementation as EmailVerificationServiceImpl
+from .service_implementation.email_verification_implementation import (
+    ServiceImplementation as EmailVerificationServiceImpl,
+)
 
 
 class SMTPService(EmailDeliveryInterface[EmailTemplateVars]):
     service_implementation: SMTPServiceInterface[EmailTemplateVars]
 
-    def __init__(self, smtp_settings: SMTPSettings,
-                 override: Union[Callable[[SMTPOverrideInput], SMTPOverrideInput], None] = None) -> None:
+    def __init__(
+        self,
+        smtp_settings: SMTPSettings,
+        override: Union[Callable[[SMTPOverrideInput], SMTPOverrideInput], None] = None,
+    ) -> None:
         transporter = Transporter(smtp_settings)
 
         oi = ServiceImplementation(transporter)
@@ -41,12 +52,20 @@ class SMTPService(EmailDeliveryInterface[EmailTemplateVars]):
 
         self.email_verification_smtp_service = EmailVerificationSMTPService(
             smtp_settings=smtp_settings,
-            override=lambda _: EmailVerificationServiceImpl(self.service_implementation)
+            override=lambda _: EmailVerificationServiceImpl(
+                self.service_implementation
+            ),
         )
 
-    async def send_email(self, template_vars: EmailTemplateVars, user_context: Dict[str, Any]) -> None:
+    async def send_email(
+        self, template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+    ) -> None:
         if isinstance(template_vars, VerificationEmailTemplateVars):
-            return await self.email_verification_smtp_service.send_email(template_vars, user_context)
+            return await self.email_verification_smtp_service.send_email(
+                template_vars, user_context
+            )
 
-        content = await self.service_implementation.get_content(template_vars, user_context)
+        content = await self.service_implementation.get_content(
+            template_vars, user_context
+        )
         await self.service_implementation.send_raw_email(content, user_context)
