@@ -39,15 +39,22 @@ class AccessTokenObj:
         self.created_time = created_time
 
 
-class RegenerateAccessTokenOkResult():
-    def __init__(self, session: SessionObj,
-                 access_token: Union[AccessTokenObj, None]):
+class RegenerateAccessTokenOkResult:
+    def __init__(self, session: SessionObj, access_token: Union[AccessTokenObj, None]):
         self.session = session
         self.access_token = access_token
 
 
-class SessionInformationResult():
-    def __init__(self, session_handle: str, user_id: str, session_data: Dict[str, Any], expiry: int, access_token_payload: Dict[str, Any], time_created: int):
+class SessionInformationResult:
+    def __init__(
+        self,
+        session_handle: str,
+        user_id: str,
+        session_data: Dict[str, Any],
+        expiry: int,
+        access_token_payload: Dict[str, Any],
+        time_created: int,
+    ):
         self.session_handle: str = session_handle
         self.user_id: str = user_id
         self.session_data: Dict[str, Any] = session_data
@@ -61,47 +68,78 @@ class RecipeInterface(ABC):
         pass
 
     @abstractmethod
-    async def create_new_session(self, request: Any, user_id: str,
-                                 access_token_payload: Union[None, Dict[str, Any]],
-                                 session_data: Union[None, Dict[str, Any]], user_context: Dict[str, Any]) -> SessionContainer:
+    async def create_new_session(
+        self,
+        request: BaseRequest,
+        user_id: str,
+        access_token_payload: Union[None, Dict[str, Any]],
+        session_data: Union[None, Dict[str, Any]],
+        user_context: Dict[str, Any],
+    ) -> SessionContainer:
         pass
 
     @abstractmethod
-    async def get_session(self, request: Any, anti_csrf_check: Union[bool, None],
-                          session_required: bool, user_context: Dict[str, Any]) -> Union[SessionContainer, None]:
+    async def get_session(
+        self,
+        request: BaseRequest,
+        anti_csrf_check: Union[bool, None],
+        session_required: bool,
+        user_context: Dict[str, Any],
+    ) -> Union[SessionContainer, None]:
         pass
 
     @abstractmethod
-    async def refresh_session(self, request: Any, user_context: Dict[str, Any]) -> SessionContainer:
+    async def refresh_session(
+        self, request: BaseRequest, user_context: Dict[str, Any]
+    ) -> SessionContainer:
         pass
 
     @abstractmethod
-    async def revoke_session(self, session_handle: str, user_context: Dict[str, Any]) -> bool:
+    async def revoke_session(
+        self, session_handle: str, user_context: Dict[str, Any]
+    ) -> bool:
         pass
 
     @abstractmethod
-    async def revoke_all_sessions_for_user(self, user_id: str, user_context: Dict[str, Any]) -> List[str]:
+    async def revoke_all_sessions_for_user(
+        self, user_id: str, user_context: Dict[str, Any]
+    ) -> List[str]:
         pass
 
     @abstractmethod
-    async def get_all_session_handles_for_user(self, user_id: str, user_context: Dict[str, Any]) -> List[str]:
+    async def get_all_session_handles_for_user(
+        self, user_id: str, user_context: Dict[str, Any]
+    ) -> List[str]:
         pass
 
     @abstractmethod
-    async def revoke_multiple_sessions(self, session_handles: List[str], user_context: Dict[str, Any]) -> List[str]:
+    async def revoke_multiple_sessions(
+        self, session_handles: List[str], user_context: Dict[str, Any]
+    ) -> List[str]:
         pass
 
     @abstractmethod
-    async def get_session_information(self, session_handle: str, user_context: Dict[str, Any]) -> SessionInformationResult:
+    async def get_session_information(
+        self, session_handle: str, user_context: Dict[str, Any]
+    ) -> Union[SessionInformationResult, None]:
         pass
 
     @abstractmethod
-    async def update_session_data(self, session_handle: str, new_session_data: Dict[str, Any], user_context: Dict[str, Any]) -> None:
+    async def update_session_data(
+        self,
+        session_handle: str,
+        new_session_data: Dict[str, Any],
+        user_context: Dict[str, Any],
+    ) -> bool:
         pass
 
     @abstractmethod
-    async def update_access_token_payload(self, session_handle: str,
-                                          new_access_token_payload: Dict[str, Any], user_context: Dict[str, Any]) -> None:
+    async def update_access_token_payload(
+        self,
+        session_handle: str,
+        new_access_token_payload: Dict[str, Any],
+        user_context: Dict[str, Any],
+    ) -> bool:
         pass
 
     @abstractmethod
@@ -113,25 +151,32 @@ class RecipeInterface(ABC):
         pass
 
     @abstractmethod
-    async def regenerate_access_token(self,
-                                      access_token: str,
-                                      new_access_token_payload: Union[Dict[str, Any], None], user_context: Dict[str, Any]) -> RegenerateAccessTokenOkResult:
+    async def regenerate_access_token(
+        self,
+        access_token: str,
+        new_access_token_payload: Union[Dict[str, Any], None],
+        user_context: Dict[str, Any],
+    ) -> Union[RegenerateAccessTokenOkResult, None]:
         pass
 
 
 class SignOutOkayResponse(APIResponse):
     def __init__(self):
-        self.status = 'OK'
+        self.status = "OK"
 
     def to_json(self) -> Dict[str, Any]:
-        return {
-            'status': self.status
-        }
+        return {"status": self.status}
 
 
 class APIOptions:
-    def __init__(self, request: BaseRequest, response: Union[None, BaseResponse],
-                 recipe_id: str, config: SessionConfig, recipe_implementation: RecipeInterface):
+    def __init__(
+        self,
+        request: BaseRequest,
+        response: Union[None, BaseResponse],
+        recipe_id: str,
+        config: SessionConfig,
+        recipe_implementation: RecipeInterface,
+    ):
         self.request: BaseRequest = request
         self.response: Union[None, BaseResponse] = response
         self.recipe_id: str = recipe_id
@@ -149,22 +194,37 @@ class APIInterface(ABC):
     # frontend anyway
 
     @abstractmethod
-    async def refresh_post(self, api_options: APIOptions, user_context: Dict[str, Any]) -> None:
+    async def refresh_post(
+        self, api_options: APIOptions, user_context: Dict[str, Any]
+    ) -> None:
         pass
 
     @abstractmethod
-    async def signout_post(self, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[SignOutOkayResponse, GeneralErrorResponse]:
+    async def signout_post(
+        self, api_options: APIOptions, user_context: Dict[str, Any]
+    ) -> Union[SignOutOkayResponse, GeneralErrorResponse]:
         pass
 
     @abstractmethod
-    async def verify_session(self, api_options: APIOptions,
-                             anti_csrf_check: Union[bool, None],
-                             session_required: bool, user_context: Dict[str, Any]) -> Union[SessionContainer, None]:
+    async def verify_session(
+        self,
+        api_options: APIOptions,
+        anti_csrf_check: Union[bool, None],
+        session_required: bool,
+        user_context: Dict[str, Any],
+    ) -> Union[SessionContainer, None]:
         pass
 
 
 class SessionContainer(ABC):
-    def __init__(self, recipe_implementation: RecipeInterface, access_token: str, session_handle: str, user_id: str, access_token_payload: Dict[str, Any]):
+    def __init__(
+        self,
+        recipe_implementation: RecipeInterface,
+        access_token: str,
+        session_handle: str,
+        user_id: str,
+        access_token_payload: Dict[str, Any],
+    ):
         self.recipe_implementation = recipe_implementation
         self.access_token = access_token
         self.session_handle = session_handle
@@ -181,15 +241,25 @@ class SessionContainer(ABC):
         pass
 
     @abstractmethod
-    async def get_session_data(self, user_context: Union[Dict[str, Any], None] = None) -> Dict[str, Any]:
+    async def get_session_data(
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> Dict[str, Any]:
         pass
 
     @abstractmethod
-    async def update_session_data(self, new_session_data: Dict[str, Any], user_context: Union[Dict[str, Any], None] = None) -> None:
+    async def update_session_data(
+        self,
+        new_session_data: Dict[str, Any],
+        user_context: Union[Dict[str, Any], None] = None,
+    ) -> None:
         pass
 
     @abstractmethod
-    async def update_access_token_payload(self, new_access_token_payload: Dict[str, Any], user_context: Union[Dict[str, Any], None] = None) -> None:
+    async def update_access_token_payload(
+        self,
+        new_access_token_payload: Dict[str, Any],
+        user_context: Union[Dict[str, Any], None] = None,
+    ) -> None:
         pass
 
     @abstractmethod
@@ -198,7 +268,8 @@ class SessionContainer(ABC):
 
     @abstractmethod
     def get_access_token_payload(
-            self, user_context: Union[Dict[str, Any], None] = None) -> Dict[str, Any]:
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> Dict[str, Any]:
         pass
 
     @abstractmethod
@@ -210,7 +281,9 @@ class SessionContainer(ABC):
         pass
 
     @abstractmethod
-    async def get_time_created(self, user_context: Union[Dict[str, Any], None] = None) -> int:
+    async def get_time_created(
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> int:
         pass
 
     @abstractmethod
@@ -221,23 +294,34 @@ class SessionContainer(ABC):
         return sync(self.get_expiry(user_context))
 
     def sync_revoke_session(
-            self, user_context: Union[Dict[str, Any], None] = None) -> None:
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> None:
         return sync(self.revoke_session(user_context=user_context))
 
     def sync_get_session_data(
-            self, user_context: Union[Dict[str, Any], None] = None) -> Dict[str, Any]:
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> Dict[str, Any]:
         return sync(self.get_session_data(user_context))
 
     def sync_get_time_created(
-            self, user_context: Union[Dict[str, Any], None] = None) -> int:
+        self, user_context: Union[Dict[str, Any], None] = None
+    ) -> int:
         return sync(self.get_time_created(user_context))
 
     def sync_update_access_token_payload(
-            self, new_access_token_payload: Dict[str, Any], user_context: Union[Dict[str, Any], None] = None) -> None:
-        return sync(self.update_access_token_payload(new_access_token_payload, user_context))
+        self,
+        new_access_token_payload: Dict[str, Any],
+        user_context: Union[Dict[str, Any], None] = None,
+    ) -> None:
+        return sync(
+            self.update_access_token_payload(new_access_token_payload, user_context)
+        )
 
     def sync_update_session_data(
-            self, new_session_data: Dict[str, Any], user_context: Union[Dict[str, Any], None] = None) -> None:
+        self,
+        new_session_data: Dict[str, Any],
+        user_context: Union[Dict[str, Any], None] = None,
+    ) -> None:
         return sync(self.update_session_data(new_session_data, user_context))
 
     # This is there so that we can do session["..."] to access some of the members of this class
