@@ -18,23 +18,31 @@ from math import ceil
 from typing import TYPE_CHECKING, Any, Dict, Union
 
 from jwt import decode
-from supertokens_python.recipe.session.with_jwt.constants import \
-    ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY
-from supertokens_python.recipe.session.with_jwt.utills import \
-    add_jwt_to_access_token_payload
+from supertokens_python.recipe.session.with_jwt.constants import (
+    ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY,
+)
+from supertokens_python.recipe.session.with_jwt.utills import (
+    add_jwt_to_access_token_payload,
+)
 from supertokens_python.utils import get_timestamp_ms
 
 if TYPE_CHECKING:
-    from supertokens_python.recipe.openid.interfaces import \
-        RecipeInterface as OpenIdRecipeInterface
+    from supertokens_python.recipe.openid.interfaces import (
+        RecipeInterface as OpenIdRecipeInterface,
+    )
     from supertokens_python.recipe.session.interfaces import SessionContainer
 
 
-def get_session_with_jwt(original_session: SessionContainer,
-                         openid_recipe_implementation: OpenIdRecipeInterface) -> SessionContainer:
+def get_session_with_jwt(
+    original_session: SessionContainer,
+    openid_recipe_implementation: OpenIdRecipeInterface,
+) -> SessionContainer:
     original_update_access_token_payload = original_session.update_access_token_payload
 
-    async def update_access_token_payload(new_access_token_payload: Dict[str, Any], user_context: Union[None, Dict[str, Any]] = None) -> None:
+    async def update_access_token_payload(
+        new_access_token_payload: Dict[str, Any],
+        user_context: Union[None, Dict[str, Any]] = None,
+    ) -> None:
         if new_access_token_payload is None:
             new_access_token_payload = {}
         if user_context is None:
@@ -42,26 +50,28 @@ def get_session_with_jwt(original_session: SessionContainer,
         access_token_payload = original_session.get_access_token_payload()
 
         if ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY not in access_token_payload:
-            return await original_update_access_token_payload(new_access_token_payload, user_context)
+            return await original_update_access_token_payload(
+                new_access_token_payload, user_context
+            )
 
-        jwt_property_name = access_token_payload[ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY]
+        jwt_property_name = access_token_payload[
+            ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY
+        ]
 
         assert jwt_property_name in access_token_payload
         existing_jwt = access_token_payload[jwt_property_name]
 
         current_time_in_seconds = ceil(get_timestamp_ms() / 1000)
         decoded_payload: Union[None, Dict[str, Any]] = decode(
-            jwt=existing_jwt,
-            options={
-                'verify_signature': False,
-                'verify_exp': False})
+            jwt=existing_jwt, options={"verify_signature": False, "verify_exp": False}
+        )
 
         if decoded_payload is None:
-            raise Exception('Error reading JWT from session')
+            raise Exception("Error reading JWT from session")
 
         jwt_expiry = 1
-        if 'exp' in decoded_payload:
-            exp = decoded_payload['exp']
+        if "exp" in decoded_payload:
+            exp = decoded_payload["exp"]
             if exp > current_time_in_seconds:
                 # it can come here if someone calls this function well after
                 # the access token and the jwt payload have expired. In this case,
@@ -76,10 +86,12 @@ def get_session_with_jwt(original_session: SessionContainer,
             user_id=original_session.get_user_id(),
             jwt_property_name=jwt_property_name,
             openid_recipe_implementation=openid_recipe_implementation,
-            user_context=user_context
+            user_context=user_context,
         )
 
-        return await original_update_access_token_payload(new_access_token_payload, user_context)
+        return await original_update_access_token_payload(
+            new_access_token_payload, user_context
+        )
 
     original_session.update_access_token_payload = update_access_token_payload
     return original_session
