@@ -14,18 +14,24 @@
 
 from typing import Union
 
-from supertokens_python.ingredients.emaildelivery import \
-    EmailDeliveryIngredient
+from supertokens_python.ingredients.emaildelivery import EmailDeliveryIngredient
 from supertokens_python.ingredients.emaildelivery.types import (
-    EmailDeliveryInterface, SMTPServiceInterface)
+    EmailDeliveryInterface,
+    SMTPServiceInterface,
+)
 from supertokens_python.recipe.emailpassword import types as ep_types
 
 from ..thirdparty.types import ThirdPartyInfo
 
 
 class User:
-    def __init__(self, user_id: str, email: str, time_joined: int,
-                 third_party_info: Union[ThirdPartyInfo, None] = None):
+    def __init__(
+        self,
+        user_id: str,
+        email: str,
+        time_joined: int,
+        third_party_info: Union[ThirdPartyInfo, None] = None,
+    ):
         self.user_id = user_id
         self.email = email
         self.time_joined = time_joined
@@ -43,7 +49,8 @@ EmailDeliveryOverrideInput = EmailDeliveryInterface[EmailTemplateVars]
 
 
 class ThirdPartyEmailPasswordIngredients:
-    def __init__(self,
-                 email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None
-                 ) -> None:
+    def __init__(
+        self,
+        email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None,
+    ) -> None:
         self.email_delivery = email_delivery
