@@ -14,29 +14,40 @@
 
 from typing import Any, Dict, Callable, Union
 
-from supertokens_python.ingredients.emaildelivery.services.smtp import (
-    Transporter)
-from supertokens_python.ingredients.emaildelivery.types import \
-    EmailDeliveryInterface, SMTPSettings
-from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import \
-    SMTPService as EmailVerificationSMTPService
-from supertokens_python.recipe.emailverification.types import VerificationEmailTemplateVars
-from supertokens_python.recipe.passwordless.emaildelivery.services.smtp import \
-    SMTPService as PlessSMTPService
-from supertokens_python.recipe.thirdpartypasswordless.types import \
-    EmailTemplateVars, SMTPOverrideInput
+from supertokens_python.ingredients.emaildelivery.services.smtp import Transporter
+from supertokens_python.ingredients.emaildelivery.types import (
+    EmailDeliveryInterface,
+    SMTPSettings,
+)
+from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import (
+    SMTPService as EmailVerificationSMTPService,
+)
+from supertokens_python.recipe.emailverification.types import (
+    VerificationEmailTemplateVars,
+)
+from supertokens_python.recipe.passwordless.emaildelivery.services.smtp import (
+    SMTPService as PlessSMTPService,
+)
+from supertokens_python.recipe.thirdpartypasswordless.types import (
+    EmailTemplateVars,
+    SMTPOverrideInput,
+)
 
 from .service_implementation import ServiceImplementation
-from .service_implementation.email_verification_implementation import \
-    ServiceImplementation as EmailVerificationServiceImpl
-from .service_implementation.passwordless_implementation import \
-    ServiceImplementation as PlessServiceImpl
+from .service_implementation.email_verification_implementation import (
+    ServiceImplementation as EmailVerificationServiceImpl,
+)
+from .service_implementation.passwordless_implementation import (
+    ServiceImplementation as PlessServiceImpl,
+)
 
 
 class SMTPService(EmailDeliveryInterface[EmailTemplateVars]):
-
-    def __init__(self, smtp_settings: SMTPSettings,
-                 override: Union[Callable[[SMTPOverrideInput], SMTPOverrideInput], None] = None) -> None:
+    def __init__(
+        self,
+        smtp_settings: SMTPSettings,
+        override: Union[Callable[[SMTPOverrideInput], SMTPOverrideInput], None] = None,
+    ) -> None:
         self.transporter = Transporter(smtp_settings)
 
         oi = ServiceImplementation(self.transporter)
@@ -44,15 +55,17 @@ class SMTPService(EmailDeliveryInterface[EmailTemplateVars]):
 
         self.ev_smtp_service = EmailVerificationSMTPService(
             smtp_settings=smtp_settings,
-            override=lambda _: EmailVerificationServiceImpl(service_implementation)
+            override=lambda _: EmailVerificationServiceImpl(service_implementation),
         )
 
         self.pless_smtp_service = PlessSMTPService(
             smtp_settings=smtp_settings,
-            override=lambda _: PlessServiceImpl(service_implementation)
+            override=lambda _: PlessServiceImpl(service_implementation),
         )
 
-    async def send_email(self, template_vars: EmailTemplateVars, user_context: Dict[str, Any]) -> None:
+    async def send_email(
+        self, template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+    ) -> None:
         if isinstance(template_vars, VerificationEmailTemplateVars):
             return await self.ev_smtp_service.send_email(template_vars, user_context)
 
