@@ -13,22 +13,31 @@
 # under the License.
 from typing import TypeVar, Union
 
-from supertokens_python.ingredients.emaildelivery import \
-    EmailDeliveryIngredient
+from supertokens_python.ingredients.emaildelivery import EmailDeliveryIngredient
 from supertokens_python.ingredients.smsdelivery import SMSDeliveryIngredient
 
-from ...ingredients.emaildelivery.types import (EmailDeliveryInterface,
-                                                SMTPServiceInterface)
-from ...ingredients.smsdelivery.types import (SMSDeliveryInterface,
-                                              TwilioServiceInterface)
+from ...ingredients.emaildelivery.types import (
+    EmailDeliveryInterface,
+    SMTPServiceInterface,
+)
+from ...ingredients.smsdelivery.types import (
+    SMSDeliveryInterface,
+    TwilioServiceInterface,
+)
 from ..passwordless import types as pless_types
 from ..thirdparty import types as tp_types
 from ..thirdparty.types import ThirdPartyInfo
 
 
 class User:
-    def __init__(self, user_id: str,
-                 email: Union[str, None], phone_number: Union[str, None], third_party_info: Union[ThirdPartyInfo, None], time_joined: int):
+    def __init__(
+        self,
+        user_id: str,
+        email: Union[str, None],
+        phone_number: Union[str, None],
+        third_party_info: Union[ThirdPartyInfo, None],
+        time_joined: int,
+    ):
         self.user_id: str = user_id
         self.email: Union[str, None] = email
         self.phone_number: Union[str, None] = phone_number
@@ -36,7 +45,7 @@ class User:
         self.third_party_info: Union[ThirdPartyInfo, None] = third_party_info
 
 
-_T = TypeVar('_T')
+_T = TypeVar("_T")
 
 # Export:
 EmailTemplateVars = Union[tp_types.EmailTemplateVars, pless_types.EmailTemplateVars]
@@ -53,9 +62,10 @@ SMSDeliveryOverrideInput = SMSDeliveryInterface[SMSTemplateVars]
 
 
 class ThirdPartyPasswordlessIngredients:
-    def __init__(self,
-                 email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None,
-                 sms_delivery: Union[SMSDeliveryIngredient[SMSTemplateVars], None] = None,
-                 ) -> None:
+    def __init__(
+        self,
+        email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None,
+        sms_delivery: Union[SMSDeliveryIngredient[SMSTemplateVars], None] = None,
+    ) -> None:
         self.email_delivery = email_delivery
         self.sms_delivery = sms_delivery
