@@ -25,26 +25,40 @@ from supertokens_python import InputAppInfo, SupertokensConfig, init
 from supertokens_python.framework.fastapi import get_middleware
 from supertokens_python.ingredients.emaildelivery import EmailDeliveryInterface
 from supertokens_python.ingredients.emaildelivery.types import (
-    EmailContent, EmailDeliveryConfig,
-    SMTPSettingsFrom, SMTPServiceInterface, SMTPSettings)
+    EmailContent,
+    EmailDeliveryConfig,
+    SMTPSettingsFrom,
+    SMTPServiceInterface,
+    SMTPSettings,
+)
 from supertokens_python.recipe import emailpassword, session
 from supertokens_python.recipe.emailpassword import (
-    InputEmailVerificationConfig, InputResetPasswordUsingTokenFeature)
-from supertokens_python.recipe.emailpassword.emaildelivery.services import \
-    SMTPService
+    InputEmailVerificationConfig,
+    InputResetPasswordUsingTokenFeature,
+)
+from supertokens_python.recipe.emailpassword.emaildelivery.services import SMTPService
 from supertokens_python.recipe.emailpassword.types import (
-    EmailTemplateVars, PasswordResetEmailTemplateVars)
+    EmailTemplateVars,
+    PasswordResetEmailTemplateVars,
+)
 from supertokens_python.recipe.emailpassword.types import User as EPUser
-from supertokens_python.recipe.emailverification.types import \
-    VerificationEmailTemplateVars
+from supertokens_python.recipe.emailverification.types import (
+    VerificationEmailTemplateVars,
+)
 from supertokens_python.recipe.session import SessionRecipe
-from supertokens_python.recipe.session.recipe_implementation import \
-    RecipeImplementation as SessionRecipeImplementation
-from supertokens_python.recipe.session.session_functions import \
-    create_new_session
-from tests.utils import (clean_st, email_verify_token_request, reset,
-                         reset_password_request, setup_st, sign_up_request,
-                         start_st)
+from supertokens_python.recipe.session.recipe_implementation import (
+    RecipeImplementation as SessionRecipeImplementation,
+)
+from supertokens_python.recipe.session.session_functions import create_new_session
+from tests.utils import (
+    clean_st,
+    email_verify_token_request,
+    reset,
+    reset_password_request,
+    setup_st,
+    sign_up_request,
+    start_st,
+)
 
 respx_mock = respx.MockRouter
 
@@ -60,37 +74,39 @@ def teardown_function(_):
     clean_st()
 
 
-@fixture(scope='function')
+@fixture(scope="function")
 async def driver_config_client():
     app = FastAPI()
     app.add_middleware(get_middleware())
 
-    @app.get('/login')
+    @app.get("/login")
     async def login(_request: Request):  # type: ignore
-        user_id = 'userId'
+        user_id = "userId"
         # await create_new_session(request, user_id, {}, {})
-        return {'userId': user_id}
+        return {"userId": user_id}
 
     return TestClient(app)
 
 
 @mark.asyncio
-async def test_reset_password_default_backward_compatibility(driver_config_client: TestClient):
+async def test_reset_password_default_backward_compatibility(
+    driver_config_client: TestClient,
+):
     "Reset password: test default backward compatibility api being called"
     app_name = ""
     email = ""
     password_reset_url = ""
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(), session.init()]
+        framework="fastapi",
+        recipe_list=[emailpassword.init(), session.init()],
     )
     start_st()
 
@@ -106,8 +122,12 @@ async def test_reset_password_default_backward_compatibility(driver_config_clien
 
     with respx_mock(assert_all_mocked=False) as mocker:
         mocker.route(host="localhost").pass_through()
-        mocked_route = mocker.post("https://api.supertokens.io/0/st/auth/password/reset").mock(side_effect=api_side_effect)
-        resp = reset_password_request(driver_config_client, "test@example.com", use_server=True)
+        mocked_route = mocker.post(
+            "https://api.supertokens.io/0/st/auth/password/reset"
+        ).mock(side_effect=api_side_effect)
+        resp = reset_password_request(
+            driver_config_client, "test@example.com", use_server=True
+        )
 
         assert resp.status_code == 200
         assert mocked_route.called
@@ -117,22 +137,24 @@ async def test_reset_password_default_backward_compatibility(driver_config_clien
 
 
 @mark.asyncio
-async def test_reset_password_default_backward_compatibility_suppress_error(driver_config_client: TestClient):
+async def test_reset_password_default_backward_compatibility_suppress_error(
+    driver_config_client: TestClient,
+):
     "Reset password: test default backward compatibility api being called, error message not sent back to user"
     app_name = ""
     email = ""
     password_reset_url = ""
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(), session.init()]
+        framework="fastapi",
+        recipe_list=[emailpassword.init(), session.init()],
     )
     start_st()
 
@@ -148,8 +170,12 @@ async def test_reset_password_default_backward_compatibility_suppress_error(driv
 
     with respx_mock(assert_all_mocked=False) as mocker:
         mocker.route(host="localhost").pass_through()
-        mocked_route = mocker.post("https://api.supertokens.io/0/st/auth/password/reset").mock(side_effect=api_side_effect)
-        resp = reset_password_request(driver_config_client, "test@example.com", use_server=True)
+        mocked_route = mocker.post(
+            "https://api.supertokens.io/0/st/auth/password/reset"
+        ).mock(side_effect=api_side_effect)
+        resp = reset_password_request(
+            driver_config_client, "test@example.com", use_server=True
+        )
 
         assert resp.status_code == 200
         assert resp.json()["status"] == "OK"
@@ -166,25 +192,30 @@ async def test_reset_password_backward_compatibility(driver_config_client: TestC
     email = ""
     password_reset_url = ""
 
-    async def custom_create_and_send_custom_email(user: EPUser, password_reset_link: str, _: Dict[str, Any]):
+    async def custom_create_and_send_custom_email(
+        user: EPUser, password_reset_link: str, _: Dict[str, Any]
+    ):
         nonlocal email, password_reset_url
         email = user.email
         password_reset_url = password_reset_link
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            reset_password_using_token_feature=InputResetPasswordUsingTokenFeature(
-                create_and_send_custom_email=custom_create_and_send_custom_email,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                reset_password_using_token_feature=InputResetPasswordUsingTokenFeature(
+                    create_and_send_custom_email=custom_create_and_send_custom_email,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
@@ -207,7 +238,9 @@ async def test_reset_password_custom_override(driver_config_client: TestClient):
     def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]):
         oi_send_email = oi.send_email
 
-        async def send_email(template_vars: EmailTemplateVars, user_context: Dict[str, Any]):
+        async def send_email(
+            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+        ):
             nonlocal email, password_reset_url
             email = template_vars.user.email
             assert isinstance(template_vars, PasswordResetEmailTemplateVars)
@@ -218,20 +251,23 @@ async def test_reset_password_custom_override(driver_config_client: TestClient):
         return oi
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_delivery=EmailDeliveryConfig(
-                service=None,
-                override=email_delivery_override,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_delivery=EmailDeliveryConfig(
+                    service=None,
+                    override=email_delivery_override,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
@@ -246,8 +282,12 @@ async def test_reset_password_custom_override(driver_config_client: TestClient):
 
     with respx_mock(assert_all_mocked=False) as mocker:
         mocker.route(host="localhost").pass_through()
-        mocked_route = mocker.post("https://api.supertokens.io/0/st/auth/password/reset").mock(side_effect=api_side_effect)
-        resp = reset_password_request(driver_config_client, "test@example.com", use_server=True)
+        mocked_route = mocker.post(
+            "https://api.supertokens.io/0/st/auth/password/reset"
+        ).mock(side_effect=api_side_effect)
+        resp = reset_password_request(
+            driver_config_client, "test@example.com", use_server=True
+        )
 
         assert resp.status_code == 200
         assert mocked_route.called
@@ -261,10 +301,16 @@ async def test_reset_password_smtp_service(driver_config_client: TestClient):
     "Reset password: test smtp service"
     email = ""
     password_reset_url = ""
-    get_content_called, send_raw_email_called, outer_override_called = False, False, False
+    get_content_called, send_raw_email_called, outer_override_called = (
+        False,
+        False,
+        False,
+    )
 
     def smtp_service_override(oi: SMTPServiceInterface[EmailTemplateVars]):
-        async def send_raw_email_override(content: EmailContent, _user_context: Dict[str, Any]):
+        async def send_raw_email_override(
+            content: EmailContent, _user_context: Dict[str, Any]
+        ):
             nonlocal send_raw_email_called, email
             send_raw_email_called = True
 
@@ -274,7 +320,9 @@ async def test_reset_password_smtp_service(driver_config_client: TestClient):
             email = content.to_email
             # Note that we aren't calling oi.send_raw_email. So Transporter won't be used.
 
-        async def get_content_override(template_vars: EmailTemplateVars, _user_context: Dict[str, Any]) -> EmailContent:
+        async def get_content_override(
+            template_vars: EmailTemplateVars, _user_context: Dict[str, Any]
+        ) -> EmailContent:
             nonlocal get_content_called, password_reset_url
             get_content_called = True
 
@@ -304,10 +352,14 @@ async def test_reset_password_smtp_service(driver_config_client: TestClient):
         override=smtp_service_override,
     )
 
-    def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]) -> EmailDeliveryInterface[EmailTemplateVars]:
+    def email_delivery_override(
+        oi: EmailDeliveryInterface[EmailTemplateVars],
+    ) -> EmailDeliveryInterface[EmailTemplateVars]:
         oi_send_email = oi.send_email
 
-        async def send_email_override(template_vars: EmailTemplateVars, user_context: Dict[str, Any]):
+        async def send_email_override(
+            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+        ):
             nonlocal outer_override_called
             outer_override_called = True
             await oi_send_email(template_vars, user_context)
@@ -316,20 +368,23 @@ async def test_reset_password_smtp_service(driver_config_client: TestClient):
         return oi
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_delivery=EmailDeliveryConfig(
-                service=email_delivery_service,
-                override=email_delivery_override,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_delivery=EmailDeliveryConfig(
+                    service=email_delivery_service,
+                    override=email_delivery_override,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
@@ -348,10 +403,16 @@ async def test_reset_password_for_non_existent_user(driver_config_client: TestCl
     "Reset password: test no callback for non-existent users"
     email = ""
     password_reset_url = ""
-    get_content_called, send_raw_email_called, outer_override_called = False, False, False
+    get_content_called, send_raw_email_called, outer_override_called = (
+        False,
+        False,
+        False,
+    )
 
     def smtp_service_override(oi: SMTPServiceInterface[EmailTemplateVars]):
-        async def send_raw_email_override(content: EmailContent, _user_context: Dict[str, Any]):
+        async def send_raw_email_override(
+            content: EmailContent, _user_context: Dict[str, Any]
+        ):
             nonlocal send_raw_email_called, email
             send_raw_email_called = True
 
@@ -361,7 +422,9 @@ async def test_reset_password_for_non_existent_user(driver_config_client: TestCl
             email = content.to_email
             # Note that we aren't calling oi.send_raw_email. So Transporter won't be used.
 
-        async def get_content_override(template_vars: EmailTemplateVars, _user_context: Dict[str, Any]) -> EmailContent:
+        async def get_content_override(
+            template_vars: EmailTemplateVars, _user_context: Dict[str, Any]
+        ) -> EmailContent:
             nonlocal get_content_called, password_reset_url
             get_content_called = True
 
@@ -391,10 +454,14 @@ async def test_reset_password_for_non_existent_user(driver_config_client: TestCl
         override=smtp_service_override,
     )
 
-    def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]) -> EmailDeliveryInterface[EmailTemplateVars]:
+    def email_delivery_override(
+        oi: EmailDeliveryInterface[EmailTemplateVars],
+    ) -> EmailDeliveryInterface[EmailTemplateVars]:
         oi_send_email = oi.send_email
 
-        async def send_email_override(template_vars: EmailTemplateVars, user_context: Dict[str, Any]):
+        async def send_email_override(
+            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+        ):
             nonlocal outer_override_called
             outer_override_called = True
             await oi_send_email(template_vars, user_context)
@@ -403,20 +470,23 @@ async def test_reset_password_for_non_existent_user(driver_config_client: TestCl
         return oi
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_delivery=EmailDeliveryConfig(
-                service=email_delivery_service,
-                override=email_delivery_override,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_delivery=EmailDeliveryConfig(
+                    service=email_delivery_service,
+                    override=email_delivery_override,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
@@ -426,34 +496,39 @@ async def test_reset_password_for_non_existent_user(driver_config_client: TestCl
 
     # User doesn't exist. So our override mustn't be called.
     assert email == ""
-    assert all([outer_override_called, get_content_called, send_raw_email_called]) is False
+    assert (
+        all([outer_override_called, get_content_called, send_raw_email_called]) is False
+    )
     assert password_reset_url == ""
 
 
 # Tests for Email Verification
 
+
 @mark.asyncio
-async def test_email_verification_default_backward_compatibility(driver_config_client: TestClient):
+async def test_email_verification_default_backward_compatibility(
+    driver_config_client: TestClient,
+):
     "Email verification: test default backward compatibility api being called"
     app_name = ""
     email = ""
     email_verify_url = ""
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(), session.init()]
+        framework="fastapi",
+        recipe_list=[emailpassword.init(), session.init()],
     )
     start_st()
 
     res = sign_up_request(driver_config_client, "test@example.com", "1234abcd")
-    user_id = res.json()['user']['id']
+    user_id = res.json()["user"]["id"]
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -476,9 +551,9 @@ async def test_email_verification_default_backward_compatibility(driver_config_c
         ).mock(side_effect=api_side_effect)
         resp = email_verify_token_request(
             driver_config_client,
-            response['accessToken']['token'],
-            response['idRefreshToken']['token'],
-            response.get('antiCsrf', ""),
+            response["accessToken"]["token"],
+            response["idRefreshToken"]["token"],
+            response.get("antiCsrf", ""),
             user_id,
             True,
         )
@@ -492,27 +567,29 @@ async def test_email_verification_default_backward_compatibility(driver_config_c
 
 
 @mark.asyncio
-async def test_email_verification_default_backward_compatibility_suppress_error(driver_config_client: TestClient):
+async def test_email_verification_default_backward_compatibility_suppress_error(
+    driver_config_client: TestClient,
+):
     "Email verification: test default backward compatibility api being called, error message not sent back to user"
     app_name = ""
     email = ""
     email_verify_url = ""
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(), session.init()]
+        framework="fastapi",
+        recipe_list=[emailpassword.init(), session.init()],
     )
     start_st()
 
     res = sign_up_request(driver_config_client, "test@example.com", "1234abcd")
-    user_id = res.json()['user']['id']
+    user_id = res.json()["user"]["id"]
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -535,9 +612,9 @@ async def test_email_verification_default_backward_compatibility_suppress_error(
         ).mock(side_effect=api_side_effect)
         resp = email_verify_token_request(
             driver_config_client,
-            response['accessToken']['token'],
-            response['idRefreshToken']['token'],
-            response.get('antiCsrf', ""),
+            response["accessToken"]["token"],
+            response["idRefreshToken"]["token"],
+            response.get("antiCsrf", ""),
             user_id,
             True,
         )
@@ -552,35 +629,42 @@ async def test_email_verification_default_backward_compatibility_suppress_error(
 
 
 @mark.asyncio
-async def test_email_verification_backward_compatibility(driver_config_client: TestClient):
+async def test_email_verification_backward_compatibility(
+    driver_config_client: TestClient,
+):
     "Email verification: test backward compatibility"
     email = ""
     email_verify_url = ""
 
-    async def custom_create_and_send_custom_email(user: EPUser, email_verification_link: str, _: Dict[str, Any]):
+    async def custom_create_and_send_custom_email(
+        user: EPUser, email_verification_link: str, _: Dict[str, Any]
+    ):
         nonlocal email, email_verify_url
         email = user.email
         email_verify_url = email_verification_link
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_verification_feature=InputEmailVerificationConfig(
-                create_and_send_custom_email=custom_create_and_send_custom_email
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_verification_feature=InputEmailVerificationConfig(
+                    create_and_send_custom_email=custom_create_and_send_custom_email
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
     res = sign_up_request(driver_config_client, "test@example.com", "1234abcd")
-    user_id = res.json()['user']['id']
+    user_id = res.json()["user"]["id"]
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -589,9 +673,9 @@ async def test_email_verification_backward_compatibility(driver_config_client: T
 
     res = email_verify_token_request(
         driver_config_client,
-        response['accessToken']['token'],
-        response['idRefreshToken']['token'],
-        response.get('antiCsrf', ""),
+        response["accessToken"]["token"],
+        response["idRefreshToken"]["token"],
+        response.get("antiCsrf", ""),
         user_id,
         True,
     )
@@ -612,7 +696,9 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
     def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]):
         oi_send_email = oi.send_email
 
-        async def send_email(template_vars: EmailTemplateVars, user_context: Dict[str, Any]):
+        async def send_email(
+            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+        ):
             nonlocal email, email_verify_url
             email = template_vars.user.email
             assert isinstance(template_vars, VerificationEmailTemplateVars)
@@ -623,25 +709,28 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
         return oi
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_delivery=EmailDeliveryConfig(
-                service=None,
-                override=email_delivery_override,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_delivery=EmailDeliveryConfig(
+                    service=None,
+                    override=email_delivery_override,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
     res = sign_up_request(driver_config_client, "test@example.com", "1234abcd")
-    user_id = res.json()['user']['id']
+    user_id = res.json()["user"]["id"]
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -662,9 +751,9 @@ async def test_email_verification_custom_override(driver_config_client: TestClie
         ).mock(side_effect=api_side_effect)
         resp = email_verify_token_request(
             driver_config_client,
-            response['accessToken']['token'],
-            response['idRefreshToken']['token'],
-            response.get('antiCsrf', ""),
+            response["accessToken"]["token"],
+            response["idRefreshToken"]["token"],
+            response.get("antiCsrf", ""),
             user_id,
             True,
         )
@@ -682,10 +771,16 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
     "Email verification: test smtp service"
     email = ""
     email_verify_url = ""
-    get_content_called, send_raw_email_called, outer_override_called = False, False, False
+    get_content_called, send_raw_email_called, outer_override_called = (
+        False,
+        False,
+        False,
+    )
 
     def smtp_service_override(oi: SMTPServiceInterface[EmailTemplateVars]):
-        async def send_raw_email_override(content: EmailContent, _user_context: Dict[str, Any]):
+        async def send_raw_email_override(
+            content: EmailContent, _user_context: Dict[str, Any]
+        ):
             nonlocal send_raw_email_called, email
             send_raw_email_called = True
 
@@ -695,7 +790,9 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
             email = content.to_email
             # Note that we aren't calling oi.send_raw_email. So Transporter won't be used.
 
-        async def get_content_override(template_vars: EmailTemplateVars, _user_context: Dict[str, Any]) -> EmailContent:
+        async def get_content_override(
+            template_vars: EmailTemplateVars, _user_context: Dict[str, Any]
+        ) -> EmailContent:
             nonlocal get_content_called, email_verify_url
             get_content_called = True
 
@@ -725,10 +822,14 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
         override=smtp_service_override,
     )
 
-    def email_delivery_override(oi: EmailDeliveryInterface[EmailTemplateVars]) -> EmailDeliveryInterface[EmailTemplateVars]:
+    def email_delivery_override(
+        oi: EmailDeliveryInterface[EmailTemplateVars],
+    ) -> EmailDeliveryInterface[EmailTemplateVars]:
         oi_send_email = oi.send_email
 
-        async def send_email_override(template_vars: EmailTemplateVars, user_context: Dict[str, Any]):
+        async def send_email_override(
+            template_vars: EmailTemplateVars, user_context: Dict[str, Any]
+        ):
             nonlocal outer_override_called
             outer_override_called = True
             await oi_send_email(template_vars, user_context)
@@ -737,25 +838,28 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
         return oi
 
     init(
-        supertokens_config=SupertokensConfig('http://localhost:3567'),
+        supertokens_config=SupertokensConfig("http://localhost:3567"),
         app_info=InputAppInfo(
             app_name="ST",
             api_domain="http://api.supertokens.io",
             website_domain="http://supertokens.io",
-            api_base_path="/auth"
+            api_base_path="/auth",
         ),
-        framework='fastapi',
-        recipe_list=[emailpassword.init(
-            email_delivery=EmailDeliveryConfig(
-                service=email_delivery_service,
-                override=email_delivery_override,
-            )
-        ), session.init()]
+        framework="fastapi",
+        recipe_list=[
+            emailpassword.init(
+                email_delivery=EmailDeliveryConfig(
+                    service=email_delivery_service,
+                    override=email_delivery_override,
+                )
+            ),
+            session.init(),
+        ],
     )
     start_st()
 
     res = sign_up_request(driver_config_client, "test@example.com", "1234abcd")
-    user_id = res.json()['user']['id']
+    user_id = res.json()["user"]["id"]
 
     s = SessionRecipe.get_instance()
     if not isinstance(s.recipe_implementation, SessionRecipeImplementation):
@@ -764,9 +868,9 @@ async def test_email_verification_smtp_service(driver_config_client: TestClient)
 
     resp = email_verify_token_request(
         driver_config_client,
-        response['accessToken']['token'],
-        response['idRefreshToken']['token'],
-        response.get('antiCsrf', ""),
+        response["accessToken"]["token"],
+        response["idRefreshToken"]["token"],
+        response.get("antiCsrf", ""),
         user_id,
         True,
     )
